==> elasticsearch-java-7.15.0-sources.jar: co/elastic/clients/elasticsearch/_types/analysis/SnowballLanguage.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch._types.analysis;

import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;
import co.elastic.clients.util.StringEnum;

@JsonpDeserializable
public enum SnowballLanguage implements StringEnum {
	Armenian("Armenian"), Basque("Basque"), Catalan("Catalan"), Danish("Danish"), Dutch("Dutch"), English(
			"English"), Finnish("Finnish"), French("French"), German("German"), German2("German2"), Hungarian(
					"Hungarian"), Italian("Italian"), Kp("Kp"), Lovins("Lovins"), Norwegian("Norwegian"), Porter(
							"Porter"), Portuguese("Portuguese"), Romanian("Romanian"), Russian(
									"Russian"), Spanish("Spanish"), Swedish("Swedish"), Turkish("Turkish");

	private final String jsonValue;

	SnowballLanguage(String jsonValue) {
		this.jsonValue = jsonValue;
	}

	public String jsonValue() {
		return this.jsonValue;
	}

	public static final StringEnum.Deserializer<SnowballLanguage> _DESERIALIZER = new StringEnum.Deserializer<>(
			SnowballLanguage.values());
}

==> elasticsearch-java-7.16.2-sources.jar: co/elastic/clients/elasticsearch/_types/analysis/SnowballLanguage.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch._types.analysis;

import co.elastic.clients.json.JsonEnum;
import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;

/**
 *
 * @see <a href=
 *      "https://github.com/elastic/elasticsearch-specification/tree/98036c3/specification/_types/analysis/languages.ts#L57-L80">API
 *      specification</a>
 */
@JsonpDeserializable
public enum SnowballLanguage implements JsonEnum {
	Armenian("Armenian"),

	Basque("Basque"),

	Catalan("Catalan"),

	Danish("Danish"),

	Dutch("Dutch"),

	English("English"),

	Finnish("Finnish"),

	French("French"),

	German("German"),

	German2("German2"),

	Hungarian("Hungarian"),

	Italian("Italian"),

	Kp("Kp"),

	Lovins("Lovins"),

	Norwegian("Norwegian"),

	Porter("Porter"),

	Portuguese("Portuguese"),

	Romanian("Romanian"),

	Russian("Russian"),

	Spanish("Spanish"),

	Swedish("Swedish"),

	Turkish("Turkish"),

	;

	private final String jsonValue;

	SnowballLanguage(String jsonValue) {
		this.jsonValue = jsonValue;
	}

	public String jsonValue() {
		return this.jsonValue;
	}

	public static final JsonEnum.Deserializer<SnowballLanguage> _DESERIALIZER = new JsonEnum.Deserializer<>(
			SnowballLanguage.values());
}
